| Title: | Interactive Document for Working with Cluster Analysis |
|---|---|
| Description: | An interactive document on the topic of cluster analysis using 'rmarkdown' and 'shiny' packages. Runtime examples are provided in the package function as well as at <https://analyticmodels.shinyapps.io/ClusterAnalysis/>. |
| Authors: | Kartikeya Bolar |
| Maintainer: | Kartikeya Bolar <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-05-14 06:02:26 UTC |
| Source: | https://github.com/cran/CLUSTShiny |
CLUSTShiny() loads interactive user interface built using R 'shiny'.
CLUSTShiny()CLUSTShiny()
Start CLUSTShiny
The interactive user interface is to provide an easy way for cluster analysis and downloading relevant plots.
Nothing
if(interactive()){ library(rmarkdown) CLUSTShiny() }if(interactive()){ library(rmarkdown) CLUSTShiny() }